@@ -7,6 +7,11 @@ import json
 import aio_pika
 import asyncio
 
+import logging
+
+logging.basicConfig(level=str(os.getenv('loglevel', 'info')).upper())
+logger = logging.getLogger(__name__)
+
 
 @click.command()
 @click.option('--config', default='config.yml', help='Path to config file')
@@ -37,10 +42,12 @@ async def create_from_config(path):
     with open(path, 'r') as ymlfile:
         cfg = yaml.safe_load(ymlfile)
 
+    logger.info(f'Config file: {path}')
     # connect to the RabbitMQ server
     for _ in range(10):
         # try to connect 10 times
         try:
+            logger.info('Connecting...')
             vh = cfg['virtualhost'] if cfg['virtualhost'] != '/' else ''
             connection_url = f"amqp://{cfg['username']}:{cfg['password']}@{cfg['host']}:{cfg['port']}/{vh}"
             connection: aio_pika.RobustConnection = await aio_pika.connect_robust(
@@ -48,20 +55,24 @@ async def create_from_config(path):
                 client_properties={"client_properties": {
                     "service": "roborabbit"}},
             )
+            logger.info('Connected!')
             break
         except ConnectionError:
             # try again
+            logger.info('Connecting...')
             await asyncio.sleep(3)
         else:
             raise ConnectionError(
                 f"Could not connect to rabbit at {cfg.url} "
                 f"with username {cfg.username}"
             )
+    logger.info('Creating channel')
     channel: aio_pika.Channel = await connection.channel()
 
     # declare the exchanges
     x_conns = {}
     for exchange in cfg['exchanges']:
+        logger.info('Declaring exchange: %s', exchange['name'])
         ex_type = exchange_type_map[exchange.get('type', 'topic')]
         x_conns[exchange['name']] = await channel.declare_exchange(
             exchange['name'],
@@ -73,6 +84,7 @@ async def create_from_config(path):
     # declare the queues
     q_conns = {}
     for queue in cfg['queues']:
+        logger.info('Declaring queue: %s', queue['name'])
         dlq_args = {
             **{"x-queue-type": queue.get("type", "quorum")},
             **queue.get("arguments", {})
@@ -104,11 +116,15 @@ async def create_from_config(path):
             raise Exception(f"Unknown to type {bindings['to']['type']}")
 
         if bindings.get('bind_options'):
+            logger.info(
+                f'Binding {from_qx.name} to {to_qx.name} using {json.dumps(bindings.get("bind_options"))}')
             await to_qx.bind(
                 from_qx,
                 arguments=bindings.get('bind_options')
             )
         else:
+            logger.info(
+                f'Binding {from_qx.name} to {to_qx.name} using routing_key "{bindings["routing_key"]}"')
             await to_qx.bind(from_qx, routing_key=bindings['routing_key'])
-
+    logger.warn('Done!')
     # TODO: Create dead letter queues
